#!/bin/bash
#
# Copyright (C) 2019 OX Software GmbH
# 
# This file is part of OX Automation.
#
# OX Automation is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# OX Automation is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with OX Automation. If not, see <http://www.gnu.org/licenses/>.
#
# Authors:
# Martin Heiland <martin.heiland@open-xchange.com>
# Nikolaos Tsapanidis <nikolaos.tsapanidis@open-xchange.com>
# Benedikt Kroening <benedikt.kroening@open-xchange.com>
#
# Note, this is for TESTING ONLY, DO NOT USE IT FOR PRODUCTION

shopt -s extglob
#================================================================================
# CONFIGURATION_VARIABLES
#================================================================================
#DN=$(hostname -f)
FQDN=$(hostname -s)

if [ "$?" -ne 0 ]; then
    FQDN=$(hostname -f)
    echo "FQDN not found, using computer name: "$FQDN
fi
DN=$FQDN

DC_PRO=false
DC_REPO_SOURCE=EXT

AS_BUILDKEY="http://software.open-xchange.com/oxbuildkey.pub"
DC_BUILDKEY="https://apt.dovecot.fi/dovecot-gpg.key"

#================================================================================
# FUNCTION_DEFINITIONS
#================================================================================





function restart_services() {
    if [[ "${DIST}" == "DebianWheezy" ]] || [[ "${DIST}" == "DebianBuster" ]] || [[ "${DIST}" == "CentOS6" ]] || [[ "${DIST}" == "RHEL6" ]]; then
        service dovecot restart
        if [[ true == "${POSTFIX}" ]]; then
            service postfix restart
        fi
    else
        systemctl unmask dovecot.service
        systemctl enable dovecot.service
        systemctl restart dovecot.service
        if [[ true == "${POSTFIX}" ]]; then
            systemctl restart postfix.service
        fi
    fi
}

# Green
function ok() {
    echo -e '\e[32m'${1}'\e[m';
}

# Red
function die() {
    echo -e '\e[1;31m'${1}'\e[m';
    exit 1;
}

function usage() {
echo -n "
  $0 [OPTIONS]

When not providing any option, the script will attempt to source \"set-install.sh\". If no information can be found, the distribution specific Dovecot package is being installed as fallback.

OPTIONS:
  -e	Sets the environment, e.g. \"release\" or \"nightly\"
  -v	Sets the version, e.g. \"2.2.26.1-10\" or \"2.2\"
  -p	Use Dovecot Pro
  -s	Installs and configures a SMTP service (Postfix)
  -h	Display this help and exit
"
}

#================================================================================
# MAIN_CODE
#================================================================================

while getopts "he::v::ps" OPTION
do
    case ${OPTION} in
        h)
            usage
            exit 1
            ;;
        e)
            DC_REPO=${OPTARG}
            ;;
        v)
            DC_VERSION=${OPTARG}
            ;;
        p)
            DC_PRO=true
            ;;
        s)
            POSTFIX=true
            ;;
        \?)
            echo "Invalid option: -${OPTARG}" >&2
            usage
            exit 1
            ;;
        :)
            echo "Option -${OPTARG} requires an argument." >&2
            exit 1
            ;;
    esac
done


if [[ -z "${DC_VERSION}" ]]; then
    echo "Version not specified, sourcing set-install.sh."
    source set-install.sh

    if [[ -z "${DC_VERSION}" ]]; then
        echo "DC_VERSION environment variable still not set"
        die "No dovecot version specified. Either set DC_VERSION in set-install.sh or as environment variable. Or use the parameter '-v'"
    fi
fi

# if [[ -z "${DC_REPO}" ]] && [[ -z "${DC_VERSION}" ]]; then
#     echo "Repository and version not specified, sourcing set-install.sh."
#     source set-install.sh
#     if [[ -n "${DC_REPO}" ]] && [[ "EXT" == "${DC_REPO_SOURCE}" ]]; then
#         if [[ -n "${DC_USER}" ]] && [[ -n "${DC_PASS}" ]]; then
#             echo "Found credentials for Dovecot Pro repository."
#             DC_REPO="${DC_REPO}"
#             DC_PRO=true

#             # todo: re-implement ...
#             die "Enterprise dovecot with custom credentials not yet re-implemented"
#         # else
#         #     echo "No Dovecot Pro repository credentials found, fallback to distro specific Dovecot"
#         #     DC_PRO=false
#         fi
#     # elif [[ -n "${DC_REPO}" ]] && [[ "OBS" == "${DC_REPO_SOURCE}" ]]; then
#     #     echo "Using internal repository source"
#     # else
#         # echo "No repo settings found at set-install.sh, fallback to distro specific Dovecot."
#         # DC_PRO=false
#     fi
# fi

